#!/bin/bash
# Script to backup phablet manually to a file. As the phablet-flash tool
# now backs up home just fine, this script backs up all the other files
# I need which don't live in the home directory
#
# Currently backs up:-
#   /var/lib/vnstat (database for vnstat tool to track data usage)
#
# Assumptions:-
# * Device already running some build of Ubuntu Touch and is connected via USB
#
# (c) 2013 Canonical - Alan Pope alan.pope@canonical.com

UBUNTU_ROOT=""
BACKUP_LOCATION="$HOME/Downloads"
DATESTAMP=`date +%Y%m%d`-`date +%H%M%S`

function adb_root {
  echo ":: Run adb root"
  adb root
  if [ $? -ne "0" ]; then
    echo ":: adb root failed"
    exit 1
  fi
}

function pause {
    echo ":: Wait $1"
    sleep $1
}


adb_root

pause 5

echo ":: Obtain device type"
DEVICETYPE=`adb shell getprop ro.cm.device | tr -d \r`
echo $DEVICETYPE | tr -d \r
echo $DATESTAMP
BACKUPFILE="$DEVICETYPE"-"$DATESTAMP"
echo "$BACKUPFILE"

echo ":: Build script to do backup"
TMP_FILE=$(mktemp)
cat > $TMP_FILE << 'EOF'
#!/bin/bash
/bin/tar zcvf /home/vnstat.tgz /var/lib/vnstat
EOF

echo ":: Run backup"
adb push $TMP_FILE $UBUNTU_ROOT/$TMP_FILE
adb shell chmod 755 $UBUNTU_ROOT/$TMP_FILE
adb shell chroot $UBUNTU_ROOT $UBUNTU_ROOT/$TMP_FILE

echo ":: Download backup to this computer"
adb pull $UBUNTU_ROOT/home/vnstat.tgz $BACKUP_LOCATION/vnstat.tgz
mv $BACKUP_LOCATION/vnstat.tgz $BACKUP_LOCATION/$BACKUPFILE-vnstat.tgz
ls -l $BACKUP_LOCATION/$BACKUPFILE-vnstat.tgz
file $BACKUP_LOCATION/$BACKUPFILE-vnstat.tgz

echo ":: Delete backup file from device"
adb shell rm -r $UBUNTU_ROOT/home/vnstat.tgz


